#!/usr/bin/env bash
#
# Put AWSLOGS configuration in place, and restart.
#
# Created: 2015-05-21 14:20 kim@infomaker.se
# Changed: 2018-01-04 13:30 kim@infomaker.se
# Changed: 2021-09-01 15:03 erik.johansson@navigaglobal.com

BS_BIN="/opt/elasticbeanstalk/bin/get-config"
CONFIG="/etc/awslogs/awslogs.conf"
AWS_REGION=$(curl http://169.254.169.254/latest/meta-data/placement/region)

# Check for correct environment, if wrong I'll die!
APP_ENV="$(/opt/elasticbeanstalk/bin/get-config environment -k APP_ENV)"

if [[ ! -z ${APP_ENV} ]]; then
   # Insert awslogs configuration
   cat <<EOF > ${CONFIG}
# ------------------------------------------
# CONFIGURATION DETAILS
# ------------------------------------------
[general]
state_file = /var/lib/awslogs/agent-state

[openresty-access_log]
file = /var/log/eb-docker/containers/openresty/access.log
log_group_name = /everyware/openresty/access.log
log_stream_name = ${APP_ENV}
datetime_format = %Y-%m-%dT%H:%M:%S%z
buffer_duration = 5000

[openresty-error_log]
file = /var/log/eb-docker/containers/openresty/error.log
log_group_name = /everyware/openresty/error.log
log_stream_name = ${APP_ENV}
datetime_format = %Y/%m/%d %H:%M:%S
buffer_duration = 5000

[php-fpm_error]
file = /var/log/eb-docker/containers/php-fpm/php-fpm-error.log
log_group_name = /everyware/php-fpm/php-fpm-error.log
log_stream_name = ${APP_ENV}
datetime_format = %d-%b-%Y %H:%M:%S
buffer_duration = 5000

[eb-engine]
file = /var/log/eb-engine.log
log_group_name = /everyware/elasticbeanstalk/eb-engine.log
log_stream_name = ${APP_ENV}
datetime_format = %d-%b-%Y %H:%M:%S
buffer_duration = 5000

[docker-events]
file = /var/log/docker-events.log
log_group_name = /everyware/elasticbeanstalk/docker-events.log
log_stream_name = ${APP_ENV}
datetime_format = %d-%b-%Y %H:%M:%S
buffer_duration = 5000

[docker-compose-events]
file = /var/log/docker-compose-events.log
log_group_name = /everyware/elasticbeanstalk/docker-compose-events.log
log_stream_name = ${APP_ENV}
datetime_format = %d-%b-%Y %H:%M:%S
buffer_duration = 5000
EOF

   # Set correct region in /etc/awslogs/awscli.conf
   sed -i '' -e "s|us-east-1|${AWS_REGION}|g" /etc/awslogs/awscli.conf

   systemctl restart awslogsd.service
else
   echo "Variable APP_ENV was not found!"
fi
