#!/bin/bash
SCRIPT_DIR="$(cd "$(dirname "${BASH_SOURCE[0]}")" >/dev/null 2>&1 && pwd)"

# Load colors and the I/O functions
source ${SCRIPT_DIR}/utils/io.sh

DEFAULT_WP_VERSION=5.8.3
DEFAULT_WP_LANGUAGE=US
DEFAULT_WP_LOCATION=www
WORDPRESS_PATHS=(
  index.php
  licens*
  readme.html
  wp-activate.php
  wp-admin/
  wp-blog-header.php
  wp-comments-post.php
  wp-content/index.php
  wp-content/languages/
  wp-content/plugins/index.php
  wp-content/themes/index.php
  wp-cron.php
  wp-includes/
  wp-links-opml.php
  wp-load.php
  wp-login.php
  wp-mail.php
  wp-settings.php
  wp-signup.php
  wp-trackback.php
  xmlrpc.php
)

WORDPRESS_CLEANUP_PATHS=(
 wp-content/themes/twenty*
 wp-content/languages/themes/twenty*
 wp-content/plugins/hello.php
 wp-content/plugins/akismet
 wp-content/languages/plugins/akismet*
 wp-config-sample.php
)

function removeWordpress() {
  local __LOCATION=${1:-www}

  ioInfo "Removing existing WordPress."

  local PATHS=("${WORDPRESS_PATHS[@]/#/${__LOCATION}/}")

  rm -rf ${PATHS[@]}
}

function wordpressVersionsAPI() {
    echo https://api.wordpress.org/core/stable-check/1.0/
}

function getStarterKitVersions() {
  local __JSON=https://composer.infomaker.io/versions.json
  local __NAME=infomaker/everyware-starter-kit

  echo $(node -e "const h=require('https'),n='${__NAME}';h.get('${__JSON}',(r)=>{let b='';r.on('data',(c)=>{b += c;});r.on('end',()=>{console.log(JSON.parse(b).filter(a=>a.name==n)[0].versions.join(' '));});}).on('error',(err)=>{console.log('Error:'+err.message);});")
}

##
 # Will fetch a list of versions based upon a version matcher.
 #+ The version can contain wildcard:
 #+ 1.2.3 - Will fetch the exact version
 #+ 1.2.* - Will fetch the latest patch on version
 #+ 1.* - Will fetch the latest minor on version
 #
function getWordpressVersions() {
  local __V=${1}
  local __JSON=$(wordpressVersionsAPI)

  echo $(node -e "const h=require('https'),vm=new RegExp('^${__V}');h.get('${__JSON}',r=>{let b='';r.on('data',c=>{b += c;});r.on('end',()=>{console.log(Object.keys(JSON.parse(b)).filter(k=>vm.test(k)).reverse().join(' '));}).on('error',err=>{console.log('Error:'+err.message);});})")
}

function installWordpress() {
  local __VERSION=${1:-${DEFAULT_WP_VERSION}}
  local __LANGUAGE=${2:-${DEFAULT_WP_LANGUAGE}}
  local __LOCATION=${3:-${DEFAULT_WP_LOCATION}}

  local __WORDPRESS_ZIP=$(createWordpressUrl ${__VERSION} "${__LANGUAGE}")
  local TEMP_DIR="./tmp/wordpress"
  local CLEANUP_PATHS=("${WORDPRESS_CLEANUP_PATHS[@]/#/${TEMP_DIR}/}")
  local CURRENT_WORDPRESS_PATHS=("${WORDPRESS_PATHS[@]/#/${__LOCATION}/}")


  ioText "(1/2) Downloading ${__WORDPRESS_ZIP}"
  curl -L -o "${TEMP_DIR}.tar.gz" --create-dirs ${__WORDPRESS_ZIP}
  ioNewLine
  ioText "(2/2) Installing WordPress"

  # Extract zip
  tar -zxf "${TEMP_DIR}.tar.gz" -C ./tmp/

  # Remove unwanted files from new Wordpress
  rm -rf ${CLEANUP_PATHS[@]}

  # Remove any current installation
  rm -rf ${CURRENT_WORDPRESS_PATHS[@]}

  # Add Wordpress to location
  rsync -a "${TEMP_DIR}/" ${__LOCATION}

  # Remove tempfiles
  rm -rf ./tmp*
}

function createWordpressUrl() {
  local __VERSION=${1:-${DEFAULT_WP_VERSION}}
  local __LANGUAGE=${2:-${DEFAULT_WP_LANGUAGE}}

  local FILENAME="wordpress-${__VERSION}"
  local DOMAIN="wordpress.org"

  case ${__LANGUAGE} in
  "DK")
    FILENAME="${FILENAME}-da_DK"
    DOMAIN="da.${DOMAIN}"
    ;;
  "FI")
    FILENAME="${FILENAME}-fi"
    DOMAIN="fi.${DOMAIN}"
    ;;
  "NB")
    FILENAME="${FILENAME}-nb_NO"
    DOMAIN="nb.${DOMAIN}"
    ;;
  "NN")
    FILENAME="${FILENAME}-nn_NO"
    DOMAIN="nn.${DOMAIN}"
    ;;
  "SE")
    FILENAME="${FILENAME}-sv_SE"
    DOMAIN="sv.${DOMAIN}"
    ;;
  esac

  echo "https://${DOMAIN}/${FILENAME}.tar.gz"
}
