#!/bin/bash
SCRIPT_DIR="$(cd "$(dirname "${BASH_SOURCE[0]}")" >/dev/null 2>&1 && pwd)"

set -e

# set current directory
cwd=$(pwd)

source ${SCRIPT_DIR}/utils/io.sh

DOCKER_COMPOSE="docker-compose -f docker-compose-local.yml"
MYSQL_CONTAINER=mysql
MYSQL_DIR=${cwd}/mysql
MYSQL_DUMP_DIR=${MYSQL_DIR}/dumps
MYSQL_DUMP_FILE="${MYSQL_DUMP_DIR}/dump-$(date +"%F-%H%M%S").sql.gz"

# Check for running environment
if [[ ! $(docker ps | grep ${MYSQL_CONTAINER}) ]]; then
    ioWarning "Can't find the mysql container. Make sure you have your local environment up and running."
    exit 1;
fi

mkdir -p ${MYSQL_DUMP_DIR}
ioInfo "Dump current database to ${MYSQL_DUMP_FILE}"
${DOCKER_COMPOSE} exec ${MYSQL_CONTAINER} mysqldump -u root everyware | gzip --best > ${MYSQL_DUMP_FILE}
ioSuccess "Done!"
